/* pcnet32.h: An AMD PCnet32 ethernet driver  header file for linux. */
/*
 *      Copyright 1996-1999 Thomas Bogendoerfer
 * 
 * 	Derived from the lance driver written 1993,1994,1995 by Donald Becker.
 * 
 * 	Copyright 1993 United States Government as represented by the
 * 	Director, National Security Agency.
 * 
 * 	This software may be used and distributed according to the terms
 * 	of the GNU Public License, incorporated herein by reference.
 *
 * 	This driver is for PCnet32 and PCnetPCI based ethercards
 */


static unsigned int pcnet32_portlist[] __initdata = {0x300, 0x320, 0x340, 0x360, 0};

static int pcnet32_debug = 1;


static const int max_interrupt_work = 20;
static const int rx_copybreak = 200;

#define PORT_AUI      0x00
#define PORT_10BT     0x01
#define PORT_GPSI     0x02
#define PORT_MII      0x03

#define PORT_PORTSEL  0x03
#define PORT_ASEL     0x04
#define PORT_100      0x40
#define PORT_FD       0x80


#define DANAS         0x80
#define XPHYRST       0x40
#define XPHYANE       0x20
#define XPHYFD        0x10
#define XPHYSP        0x08
#define ASELBIT       0x02

/*
 * table to translate option values from tulip
 * to internal options
 */
static unsigned char options_mapping[] = {
    PORT_ASEL,			   /*  0 Auto-select      */
    PORT_AUI,			   /*  1 BNC/AUI          */
    PORT_AUI,			   /*  2 AUI/BNC          */ 
    PORT_ASEL,			   /*  3 not supported    */
    PORT_10BT | PORT_FD,	   /*  4 10baseT-FD       */
    PORT_ASEL,			   /*  5 not supported    */
    PORT_ASEL,			   /*  6 not supported    */
    PORT_ASEL,			   /*  7 not supported    */
    PORT_ASEL,			   /*  8 not supported    */
    PORT_MII,		           /*  9 MII 10baseT      */
    PORT_MII | PORT_FD,            /* 10 MII 10baseT-FD   */
    PORT_MII,			   /* 11 MII (autosel)    */
    PORT_10BT,			   /* 12 10BaseT	  */
    PORT_MII | PORT_100,	   /* 13 MII 100BaseTx    */
    PORT_MII | PORT_100 | PORT_FD, /* 14 MII 100BaseTx-FD */
    PORT_ASEL			   /* 15 not supported    */
};

#define MAX_UNITS 8
static int options[MAX_UNITS] = {0, };
static int full_duplex[MAX_UNITS] = {0, };
static int led_program[MAX_UNITS] = {0, };


/*
 * Set the number of Tx and Rx buffers, using Log_2(# buffers).
 * Reasonable default values are 4 Tx buffers, and 16 Rx buffers.
 * That translates to 2 (4 == 2^^2) and 4 (16 == 2^^4).
 */
#ifndef PCNET32_LOG_TX_BUFFERS
#define PCNET32_LOG_TX_BUFFERS 4
#define PCNET32_LOG_RX_BUFFERS 4
#endif

#define TX_RING_SIZE			(1 << (PCNET32_LOG_TX_BUFFERS))
#define TX_RING_MOD_MASK		(TX_RING_SIZE - 1)
#define TX_RING_LEN_BITS		((PCNET32_LOG_TX_BUFFERS) << 12)

#define RX_RING_SIZE			(1 << (PCNET32_LOG_RX_BUFFERS))
#define RX_RING_MOD_MASK		(RX_RING_SIZE - 1)
#define RX_RING_LEN_BITS		((PCNET32_LOG_RX_BUFFERS) << 4)

#define PKT_BUF_SZ		1544

/* Offsets from base I/O address. */
#define PCNET32_WIO_RDP		0x10
#define PCNET32_WIO_RAP		0x12
#define PCNET32_WIO_RESET	0x14
#define PCNET32_WIO_BDP		0x16

#define PCNET32_DWIO_RDP	0x10
#define PCNET32_DWIO_RAP	0x14
#define PCNET32_DWIO_RESET	0x18
#define PCNET32_DWIO_BDP	0x1C

#define PCNET32_TOTAL_SIZE 0x20

/* some PCI ids */
#ifndef PCI_DEVICE_ID_AMD_LANCE
#define PCI_VENDOR_ID_AMD	      0x1022
#define PCI_DEVICE_ID_AMD_LANCE	      0x2000
#endif
#ifndef PCI_DEVICE_ID_AMD_PCNETHOME
#define PCI_DEVICE_ID_AMD_PCNETHOME   0x2001
#endif


#define CRC_POLYNOMIAL_LE 0xedb88320UL  /* Ethernet CRC, little endian */

typedef struct pcnet32_LED  {
     int index;
     u32 led0;
     u32 led1;
     u32 led2;
     u32 led3;
 }LED_struct;

/**********Sample structure*********
Knowledgeable user to alter the pcnet32_led
structure to reflect the desired values.
Refer to led documentation.
---------------------------------------
LED_struct pcnet32_led[MAX_UNITS] =  {
{0, 0xc0, 0xb0, 0x4088, 0x81},
{1, 0xc0, 0xb0, 0x4088, 0x81},
{2, 0xc0, 0xb0, 0x4088, 0x81},
{3, 0xc0, 0xb0, 0x4088, 0x81},
{4, 0xc0, 0xb0, 0x4088, 0x81},
{5, 0xc0, 0xb0, 0x4088, 0x81},
{6, 0xc0, 0xb0, 0x4088, 0x81},
{7, 0xc0, 0xb0, 0x4088, 0x81}
};
*************************************/
/***Make changes in the structure***/ 
LED_struct pcnet32_led[MAX_UNITS] =  {
{0, 0xc0, 0xb0, 0x4088, 0x81},
{1, 0xc0, 0xb0, 0x4088, 0x81},
{2, 0xc0, 0xb0, 0x4088, 0x81},
{3, 0xc0, 0xb0, 0x4088, 0x81},
{4, 0xc0, 0xb0, 0x4088, 0x81},
{5, 0xc0, 0xb0, 0x4088, 0x81},
{6, 0xc0, 0xb0, 0x4088, 0x81},
{7, 0xc0, 0xb0, 0x4088, 0x81}
};

